==> medlogics-common-classes-1.0.jar: com/floreantpos/report/model/ReferralCommissionReportModel.java <==
package com.floreantpos.report.model;

import com.floreantpos.report.ReferralCommissionReportData;
import com.floreantpos.swing.ListTableModel;

public class ReferralCommissionReportModel extends ListTableModel {
	public ReferralCommissionReportModel() {
		super(new String[] { "referralType", "referralBy", "receivable", "due", "received", "labDoctorFee", "RFonReport", "ofcNet", "RFonNetSales", "RFpayable",
				"RFpaid", "RFdue", "ofcTotal", "orderId", "orderDate", "patientName", "patientMobileNo" });
	}

	@Override
	public Object getValueAt(int rowIndex, int columnIndex) {
		ReferralCommissionReportData reportData = (ReferralCommissionReportData) rows.get(rowIndex);

		double officeNet = reportData.getReceived() - (reportData.getLabDoctorFee() + reportData.getAgentCommissionOnReport());
		double officeTotal = officeNet - reportData.getAgentCommissionOnNetSales();
		double agentFeeGrossPayable = reportData.getAgentCommissionOnReport() + reportData.getAgentCommissionOnNetSales();

		switch (columnIndex) {
			case 0:
				return reportData.getReferralType();

			case 1:
				return reportData.getReferralBy();

			case 2:
				return reportData.getReceivable();

			case 3:
				return reportData.getDue();

			case 4:
				return reportData.getReceived();

			case 5:
				return reportData.getLabDoctorFee();

			case 6:
				return reportData.getAgentCommissionOnReport();

			case 7:
				return officeNet;

			case 8:
				return reportData.getAgentCommissionOnNetSales();

			case 9:
				return agentFeeGrossPayable;

			case 10:
				return reportData.getReferrerFeePaidAmount();

			case 11:
				return reportData.getReferrerFeeDueAmount();

			case 12:
				return officeTotal;

			case 13:
				return reportData.getOrderId();

			case 14:
				return reportData.getOrderDate();

			case 15:
				return reportData.getPatientName();

			case 16:
				return reportData.getPatientMobileNo();

		}
		return null;
	}

}

==> medlogics-common-classes-1.1-20250829.120616-340.jar: com/floreantpos/report/model/ReferralCommissionReportModel.java <==
package com.floreantpos.report.model;

import com.floreantpos.report.ReferralCommissionReportData;
import com.floreantpos.swing.ListTableModel;

public class ReferralCommissionReportModel extends ListTableModel {
	public ReferralCommissionReportModel() {
		super(new String[] { "referralType", "referralBy", "receivable", "due", "received", "labDoctorFee", "RFonReport", "ofcNet", "RFonNetSales", "RFpayable",
				"RFpaid", "RFdue", "ofcTotal", "orderId", "orderDate", "patientName", "patientMobileNo", "referralId", "patientId", "totalRfAmount",
				"dueCollection" });
	}

	@Override
	public Object getValueAt(int rowIndex, int columnIndex) {
		ReferralCommissionReportData reportData = (ReferralCommissionReportData) rows.get(rowIndex);

		switch (columnIndex) {
			case 0:
				return reportData.getReferralType();

			case 1:
				return reportData.getReferralBy();

			case 2:
				return reportData.getReceivable();

			case 3:
				return reportData.getDue();

			case 4:
				return reportData.getReceived();

			case 5:
				return reportData.getLabDoctorFee();

			case 6:
				return reportData.getRfOnReport();

			case 7:
				return reportData.getOfficeNet();

			case 8:
				return reportData.getRfOnNetSales();

			case 9:
				return reportData.getRfPayableAmount();

			case 10:
				return reportData.getRfPaid();

			case 11:
				return reportData.getRfFeeDue();

			case 12:
				return reportData.getOfficeTotal();

			case 13:
				return reportData.getOrderId();

			case 14:
				return reportData.getOrderDate();

			case 15:
				return reportData.getPatientName();

			case 16:
				return reportData.getPatientMobileNo();

			case 17:
				return reportData.getReferralId();

			case 18:
				return reportData.getPatientId();
				
			case 19:
				return reportData.getTotalRF();
				
			case 20:
				return reportData.getDueColl();

		}
		return null;
	}

}
